@@ -1,9 +1,12 @@
-from typing import Any, Callable, Dict, List, Optional, Sequence, Union
+from collections.abc import Sequence
+from typing import Annotated, Any, Callable, Optional, Union
 
+from annotated_doc import Doc
 from fastapi import params
 from fastapi._compat import Undefined
 from fastapi.openapi.models import Example
-from typing_extensions import Annotated, Doc, deprecated
+from pydantic import AliasChoices, AliasPath
+from typing_extensions import Literal, deprecated
 
 _Unset: Any = Undefined
 
@@ -52,10 +55,8 @@ def Path(  # noqa: N802
             """
         ),
     ] = _Unset,
-    # TODO: update when deprecating Pydantic v1, import these types
-    # validation_alias: str | AliasPath | AliasChoices | None
     validation_alias: Annotated[
-        Union[str, None],
+        Union[str, AliasPath, AliasChoices, None],
         Doc(
             """
             'Whitelist' validation step. The parameter field will be the single one
@@ -208,7 +209,7 @@ def Path(  # noqa: N802
         ),
     ] = _Unset,
     examples: Annotated[
-        Optional[List[Any]],
+        Optional[list[Any]],
         Doc(
             """
             Example values for this field.
@@ -223,7 +224,7 @@ def Path(  # noqa: N802
         ),
     ] = _Unset,
     openapi_examples: Annotated[
-        Optional[Dict[str, Example]],
+        Optional[dict[str, Example]],
         Doc(
             """
             OpenAPI-specific examples.
@@ -261,7 +262,7 @@ def Path(  # noqa: N802
         ),
     ] = True,
     json_schema_extra: Annotated[
-        Union[Dict[str, Any], None],
+        Union[dict[str, Any], None],
         Doc(
             """
             Any additional JSON schema data.
@@ -377,10 +378,8 @@ def Query(  # noqa: N802
             """
         ),
     ] = _Unset,
-    # TODO: update when deprecating Pydantic v1, import these types
-    # validation_alias: str | AliasPath | AliasChoices | None
     validation_alias: Annotated[
-        Union[str, None],
+        Union[str, AliasPath, AliasChoices, None],
         Doc(
             """
             'Whitelist' validation step. The parameter field will be the single one
@@ -533,7 +532,7 @@ def Query(  # noqa: N802
         ),
     ] = _Unset,
     examples: Annotated[
-        Optional[List[Any]],
+        Optional[list[Any]],
         Doc(
             """
             Example values for this field.
@@ -548,7 +547,7 @@ def Query(  # noqa: N802
         ),
     ] = _Unset,
     openapi_examples: Annotated[
-        Optional[Dict[str, Example]],
+        Optional[dict[str, Example]],
         Doc(
             """
             OpenAPI-specific examples.
@@ -586,7 +585,7 @@ def Query(  # noqa: N802
         ),
     ] = True,
     json_schema_extra: Annotated[
-        Union[Dict[str, Any], None],
+        Union[dict[str, Any], None],
         Doc(
             """
             Any additional JSON schema data.
@@ -681,10 +680,8 @@ def Header(  # noqa: N802
             """
         ),
     ] = _Unset,
-    # TODO: update when deprecating Pydantic v1, import these types
-    # validation_alias: str | AliasPath | AliasChoices | None
     validation_alias: Annotated[
-        Union[str, None],
+        Union[str, AliasPath, AliasChoices, None],
         Doc(
             """
             'Whitelist' validation step. The parameter field will be the single one
@@ -848,7 +845,7 @@ def Header(  # noqa: N802
         ),
     ] = _Unset,
     examples: Annotated[
-        Optional[List[Any]],
+        Optional[list[Any]],
         Doc(
             """
             Example values for this field.
@@ -863,7 +860,7 @@ def Header(  # noqa: N802
         ),
     ] = _Unset,
     openapi_examples: Annotated[
-        Optional[Dict[str, Example]],
+        Optional[dict[str, Example]],
         Doc(
             """
             OpenAPI-specific examples.
@@ -901,7 +898,7 @@ def Header(  # noqa: N802
         ),
     ] = True,
     json_schema_extra: Annotated[
-        Union[Dict[str, Any], None],
+        Union[dict[str, Any], None],
         Doc(
             """
             Any additional JSON schema data.
@@ -997,10 +994,8 @@ def Cookie(  # noqa: N802
             """
         ),
     ] = _Unset,
-    # TODO: update when deprecating Pydantic v1, import these types
-    # validation_alias: str | AliasPath | AliasChoices | None
     validation_alias: Annotated[
-        Union[str, None],
+        Union[str, AliasPath, AliasChoices, None],
         Doc(
             """
             'Whitelist' validation step. The parameter field will be the single one
@@ -1153,7 +1148,7 @@ def Cookie(  # noqa: N802
         ),
     ] = _Unset,
     examples: Annotated[
-        Optional[List[Any]],
+        Optional[list[Any]],
         Doc(
             """
             Example values for this field.
@@ -1168,7 +1163,7 @@ def Cookie(  # noqa: N802
         ),
     ] = _Unset,
     openapi_examples: Annotated[
-        Optional[Dict[str, Example]],
+        Optional[dict[str, Example]],
         Doc(
             """
             OpenAPI-specific examples.
@@ -1206,7 +1201,7 @@ def Cookie(  # noqa: N802
         ),
     ] = True,
     json_schema_extra: Annotated[
-        Union[Dict[str, Any], None],
+        Union[dict[str, Any], None],
         Doc(
             """
             Any additional JSON schema data.
@@ -1282,7 +1277,7 @@ def Body(  # noqa: N802
         ),
     ] = _Unset,
     embed: Annotated[
-        bool,
+        Union[bool, None],
         Doc(
             """
             When `embed` is `True`, the parameter will be expected in a JSON body as a
@@ -1294,7 +1289,7 @@ def Body(  # noqa: N802
             [FastAPI docs for Body - Multiple Parameters](https://fastapi.tiangolo.com/tutorial/body-multiple-params/#embed-a-single-body-parameter).
             """
         ),
-    ] = False,
+    ] = None,
     media_type: Annotated[
         str,
         Doc(
@@ -1324,10 +1319,8 @@ def Body(  # noqa: N802
             """
         ),
     ] = _Unset,
-    # TODO: update when deprecating Pydantic v1, import these types
-    # validation_alias: str | AliasPath | AliasChoices | None
     validation_alias: Annotated[
-        Union[str, None],
+        Union[str, AliasPath, AliasChoices, None],
         Doc(
             """
             'Whitelist' validation step. The parameter field will be the single one
@@ -1480,7 +1473,7 @@ def Body(  # noqa: N802
         ),
     ] = _Unset,
     examples: Annotated[
-        Optional[List[Any]],
+        Optional[list[Any]],
         Doc(
             """
             Example values for this field.
@@ -1495,7 +1488,7 @@ def Body(  # noqa: N802
         ),
     ] = _Unset,
     openapi_examples: Annotated[
-        Optional[Dict[str, Example]],
+        Optional[dict[str, Example]],
         Doc(
             """
             OpenAPI-specific examples.
@@ -1533,7 +1526,7 @@ def Body(  # noqa: N802
         ),
     ] = True,
     json_schema_extra: Annotated[
-        Union[Dict[str, Any], None],
+        Union[dict[str, Any], None],
         Doc(
             """
             Any additional JSON schema data.
@@ -1639,10 +1632,8 @@ def Form(  # noqa: N802
             """
         ),
     ] = _Unset,
-    # TODO: update when deprecating Pydantic v1, import these types
-    # validation_alias: str | AliasPath | AliasChoices | None
     validation_alias: Annotated[
-        Union[str, None],
+        Union[str, AliasPath, AliasChoices, None],
         Doc(
             """
             'Whitelist' validation step. The parameter field will be the single one
@@ -1795,7 +1786,7 @@ def Form(  # noqa: N802
         ),
     ] = _Unset,
     examples: Annotated[
-        Optional[List[Any]],
+        Optional[list[Any]],
         Doc(
             """
             Example values for this field.
@@ -1810,7 +1801,7 @@ def Form(  # noqa: N802
         ),
     ] = _Unset,
     openapi_examples: Annotated[
-        Optional[Dict[str, Example]],
+        Optional[dict[str, Example]],
         Doc(
             """
             OpenAPI-specific examples.
@@ -1848,7 +1839,7 @@ def Form(  # noqa: N802
         ),
     ] = True,
     json_schema_extra: Annotated[
-        Union[Dict[str, Any], None],
+        Union[dict[str, Any], None],
         Doc(
             """
             Any additional JSON schema data.
@@ -1953,10 +1944,8 @@ def File(  # noqa: N802
             """
         ),
     ] = _Unset,
-    # TODO: update when deprecating Pydantic v1, import these types
-    # validation_alias: str | AliasPath | AliasChoices | None
     validation_alias: Annotated[
-        Union[str, None],
+        Union[str, AliasPath, AliasChoices, None],
         Doc(
             """
             'Whitelist' validation step. The parameter field will be the single one
@@ -2109,7 +2098,7 @@ def File(  # noqa: N802
         ),
     ] = _Unset,
     examples: Annotated[
-        Optional[List[Any]],
+        Optional[list[Any]],
         Doc(
             """
             Example values for this field.
@@ -2124,7 +2113,7 @@ def File(  # noqa: N802
         ),
     ] = _Unset,
     openapi_examples: Annotated[
-        Optional[Dict[str, Example]],
+        Optional[dict[str, Example]],
         Doc(
             """
             OpenAPI-specific examples.
@@ -2162,7 +2151,7 @@ def File(  # noqa: N802
         ),
     ] = True,
     json_schema_extra: Annotated[
-        Union[Dict[str, Any], None],
+        Union[dict[str, Any], None],
         Doc(
             """
             Any additional JSON schema data.
@@ -2244,6 +2233,26 @@ def Depends(  # noqa: N802
             """
         ),
     ] = True,
+    scope: Annotated[
+        Union[Literal["function", "request"], None],
+        Doc(
+            """
+            Mainly for dependencies with `yield`, define when the dependency function
+            should start (the code before `yield`) and when it should end (the code
+            after `yield`).
+
+            * `"function"`: start the dependency before the *path operation function*
+                that handles the request, end the dependency after the *path operation
+                function* ends, but **before** the response is sent back to the client.
+                So, the dependency function will be executed **around** the *path operation
+                **function***.
+            * `"request"`: start the dependency before the *path operation function*
+                that handles the request (similar to when using `"function"`), but end
+                **after** the response is sent back to the client. So, the dependency
+                function will be executed **around** the **request** and response cycle.
+            """
+        ),
+    ] = None,
 ) -> Any:
     """
     Declare a FastAPI dependency.
@@ -2274,7 +2283,7 @@ def Depends(  # noqa: N802
         return commons
     ```
     """
-    return params.Depends(dependency=dependency, use_cache=use_cache)
+    return params.Depends(dependency=dependency, use_cache=use_cache, scope=scope)
 
 
 def Security(  # noqa: N802
@@ -2298,7 +2307,7 @@ def Security(  # noqa: N802
             dependency.
 
             The term "scope" comes from the OAuth2 specification, it seems to be
-            intentionaly vague and interpretable. It normally refers to permissions,
+            intentionally vague and interpretable. It normally refers to permissions,
             in cases to roles.
 
             These scopes are integrated with OpenAPI (and the API docs at `/docs`).
@@ -2343,7 +2352,7 @@ def Security(  # noqa: N802
     ```python
     from typing import Annotated
 
-    from fastapi import Depends, FastAPI
+    from fastapi import Security, FastAPI
 
     from .db import User
     from .security import get_current_active_user
